==> xled-0.3.0.tar.gz: xled-0.3.0/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""The setup script."""

import sys

from setuptools import find_packages, setup

with open("README.rst") as readme_file:
    readme = readme_file.read()

with open("HISTORY.rst") as history_file:
    history = history_file.read()

requirements = [
    "arpreq",
    "click-log",
    "Click>=6.0",
    "cryptography",
    "netaddr",
    "pyzmq",
    "requests",
    "tornado",
    "requests-toolbelt",
]
tests_requirements = ["vcrpy-unittest"]

if sys.version_info < (3, 3):
    requirements.append("ipaddress")

setup(
    name="xled",
    # bumpversion v0.5.3 doesn't handle version string in double quotes
    # correctly so prevent Black to format it:
    # fmt: off
    version='0.3.0',
    # fmt: on
    description=(
        "Python library for Twinkly - Smart Decoration LED lights for Christmas."
    ),
    long_description=readme + "\n\n" + history,
    author="Pavol Babinčák",
    author_email="scroolik@gmail.com",
    url="https://github.com/scrool/xled",
    packages=find_packages(include=["xled"]),
    entry_points={"console_scripts": ["xled=xled.cli:main"]},
    include_package_data=True,
    install_requires=requirements,
    tests_require=tests_requirements,
    license="MIT license",
    zip_safe=False,
    keywords="xled,twinkly",
    classifiers=[
        "Development Status :: 2 - Pre-Alpha",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Natural Language :: English",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
    ],
    test_suite="tests",
)

==> xled-0.3.1.tar.gz: xled-0.3.1/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""The setup script."""

import sys

from setuptools import find_packages, setup

with open("README.rst") as readme_file:
    readme = readme_file.read()

with open("HISTORY.rst") as history_file:
    history = history_file.read()

requirements = [
    "arpreq",
    "click-log",
    "Click>=6.0",
    "cryptography",
    "netaddr",
    "pyzmq",
    "requests",
    "tornado",
    "requests-toolbelt",
]
tests_requirements = ["vcrpy-unittest"]

if sys.version_info < (3, 3):
    requirements.append("ipaddress")

setup(
    name="xled",
    # bumpversion v0.5.3 doesn't handle version string in double quotes
    # correctly so prevent Black to format it:
    # fmt: off
    version='0.3.1',
    # fmt: on
    description=(
        "Python library and command line interface to control "
        "Twinkly - Smart Decoration LED lights for Christmas."
    ),
    long_description=readme + "\n\n" + history,
    author="Pavol Babinčák",
    author_email="scroolik@gmail.com",
    url="https://github.com/scrool/xled",
    packages=find_packages(include=["xled"]),
    entry_points={"console_scripts": ["xled=xled.cli:main"]},
    include_package_data=True,
    install_requires=requirements,
    tests_require=tests_requirements,
    license="MIT license",
    zip_safe=False,
    keywords="xled,twinkly",
    classifiers=[
        "Development Status :: 2 - Pre-Alpha",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Natural Language :: English",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
    ],
    test_suite="tests",
)
